'use strict';

angular.module('datasid.controllers', []).
    controller('MainCtrl', function ($scope, $rootScope, $state) {
        $scope.bigButtons = {
            collapsed: false,
            rowClass: "",
            order: "",
            current: null,
            items: [
                {
                    title: "Acompanhamento",
                    icon: "icon-charts",
                    color: "dark",
                    link: "#/attendance",
                    section: "attendance",
                    active: false
                },
                {
                    title: "Instalação",
                    icon: "icon-install",
                    color: "medium",
                    link: "#/install",
                    section: "install",
                    active: false
                },
                {
                    title: "Documentação",
                    icon: "icon-doc",
                    color: "light",
                    link: "#/doc",
                    section: "doc",
                    active: false
                },
            ],
        }

        $scope.$on("$stateChangeSuccess", function(event, toState, toParams, fromState, fromParams) {
            if ((typeof $state.current !== "undefined") && ("section" in $state.current)) {
                angular.forEach($scope.bigButtons.items, function (item) {
                    item.active = (item.section === $state.current.section);
                    if (item.active)
                        $scope.bigButtons.current = item;
                });
            }
        })
    }).

    controller('RootCtrl', function ($scope, $rootScope) {
        $scope.bigButtons.collapsed = false;
        $scope.bigButtons.rowClass = "";
        $scope.bigButtons.order = "";
    }).

    controller('InstallCtrl', function ($scope, $rootScope) {
        $scope.bigButtons.collapsed = true;
        $scope.bigButtons.rowClass = "medium";
        $scope.bigButtons.order = "-active";

        $scope.useProxy = false;
    }).

    controller('DocCtrl', function ($scope, $rootScope) {
        $scope.bigButtons.collapsed = true;
        $scope.bigButtons.rowClass = "light";
        $scope.bigButtons.order = "-active";
    }).

    controller('AttendanceCtrl', function ($scope, $rootScope) {
        $scope.bigButtons.collapsed = true;
        $scope.bigButtons.rowClass = "dark";
        $scope.bigButtons.order = "-active";
    }).

    controller('AvailCtrl', function ($scope, $rootScope, $state, $location, AvailFactory) {
        if (typeof $state.params.city !== 'undefined')
            $state.params.level = 3;
        else if (typeof $state.params.state !== 'undefined')
            $state.params.level = 2;
        else if (typeof $state.params.region !== 'undefined')
            $state.params.level = 1;
        else
            $state.params.level = 0;

        $scope.barChart = {
            render: function (element) {
                var config = DefaultCharts.barChart;
                config.chart.renderTo = element[0];
                config.plotOptions.series.events = {
                    click: function(event) {
                        $scope.$apply(function () {
                            $location.path($location.path() + '/' + event.point.category);
                        });
                    }
                };

                $scope.barChart.chart = new Highcharts.Chart(config);
                $scope.barChart.load();
            },

            load: function () {
                var options = $state.params;
                options.type = 'bar';

                AvailFactory.get(options, function (data) {
                    $scope.barChart.chart.xAxis[0].setCategories(data.categories);
                    $scope.barChart.chart.series[0].setData(data.green);
                    $scope.barChart.chart.series[1].setData(data.yellow);
                    $scope.barChart.chart.series[2].setData(data.red);
                });
            }
        };

        $scope.pieChart = {
            render: function (element) {
                var config = DefaultCharts.pieChart;
                config.chart.renderTo = element[0];

                $scope.pieChart.chart = new Highcharts.Chart(config);
                $scope.pieChart.load();
            },

            load: function () {
                var options = $state.params;
                options.type = 'pie';

                AvailFactory.get(options, function (data) {
                    $scope.pieChart.chart.series[0].setData([
                        ['Menos de\n10 dias', data.green[0]],
                        ['Entre 11\ne 30 dias', data.yellow[0]],
                        ['Mais de\n30 dias', data.red[0]]
                    ]);
                });
            }
        };

        $scope.histChart = {
            render: function (element) {
                console.log(element[0]);
                var config = DefaultCharts.histChart;
                config.chart.renderTo = element[0];

                $scope.histChart.chart = new Highcharts.Chart(config);
                $scope.histChart.load();
            },

            load: function () {
                var options = $state.params;
                options.type = 'hist';

                AvailFactory.get(options, function (data) {
                    $scope.histChart.chart.xAxis[0].setCategories(data.categories);
                    $scope.histChart.chart.series[0].setData(data.green);
                    $scope.histChart.chart.series[1].setData(data.yellow);
                    $scope.histChart.chart.series[2].setData(data.red);
                });
            }
        };
    });
